iiif changelog
=============

2012-03-21 v0.1.0
- First stab at IIIF API v0.1

2013-05-21 v0.2.0
- Reorganized, aims for IIIF API v1.0
  (http://www-sul.stanford.edu/iiif/image-api/)
- PIL library support (IIIFManipulatorPIL) and null tested, the netpbm
  version (IIIFManipulatorNetpbm) has not been updated/tested and is 
  likely broken.
- Designed to work with Loris for for Open Seadragon demo
  (https://github.com/zimeon/loris)
- Add GPL

2014-04-22 v0.3.0
- Change pypi package name from i3f to iiif

2014-04-28 v0.4.0
- Aim to support IIIF API v1.1 and v2.0
- Added generation of static file tiles for OpenSeadragon
- Included demo for OpenSeadragon with static file tiles
